@@ -1,14 +1,10 @@
 from cmdbox.app import feature
 from cmdbox.app.web import Web
-from fastapi import FastAPI, Request, Response
+from fastapi import FastAPI, Request, Response, HTTPException
 import logging
 
 
 class BbforceCmd(feature.WebFeature):
-    def __init__(self):
-        super().__init__()
-
-
     def route(self, web:Web, app:FastAPI) -> None:
         """
         webモードのルーティングを設定します
@@ -19,9 +15,9 @@ class BbforceCmd(feature.WebFeature):
         """
         @app.get('/bbforce_cmd')
         async def del_cmd(req:Request, res:Response):
-            signin = web.check_signin(req, res)
+            signin = web.signin.check_signin(req, res)
             if signin is not None:
-                return str(dict(warn=f'Please log in to retrieve session.'))
+                raise HTTPException(status_code=401, detail=self.DEFAULT_401_MESSAGE)
             if web.logger.level == logging.DEBUG:
                 web.logger.debug(f"web.bbforce_cmd")
             try:
