@@ -1,14 +1,10 @@
-from cmdbox import version
 from cmdbox.app import feature
 from cmdbox.app.web import Web
-from fastapi import FastAPI, Request, Response
+from fastapi import FastAPI, Request, Response, HTTPException
 from fastapi.responses import PlainTextResponse
 
 
 class Copyright(feature.WebFeature):
-    def __init__(self):
-        super().__init__()
-
     def route(self, web:Web, app:FastAPI) -> None:
         """
         webモードのルーティングを設定します
@@ -19,8 +15,8 @@ class Copyright(feature.WebFeature):
         """
         @app.get('/copyright', response_class=PlainTextResponse)
         async def copyright(req:Request, res:Response):
-            signin = web.check_signin(req, res)
+            signin = web.signin.check_signin(req, res)
             if signin is not None:
-                return str(dict(warn=f'Please log in to retrieve session.'))
-            return version.__copyright__
+                raise HTTPException(status_code=401, detail=self.DEFAULT_401_MESSAGE)
+            return self.ver.__copyright__
 
