@@ -1,13 +1,9 @@
 from cmdbox.app import feature
 from cmdbox.app.web import Web
-from fastapi import FastAPI, Request, Response
+from fastapi import FastAPI, Request, Response, HTTPException
 
 
 class GetCmdChoices(feature.WebFeature):
-    def __init__(self):
-        super().__init__()
-
-
     def route(self, web:Web, app:FastAPI) -> None:
         """
         webモードのルーティングを設定します
@@ -18,11 +14,11 @@ class GetCmdChoices(feature.WebFeature):
         """
         @app.post('/gui/get_cmd_choices')
         async def get_cmd_choices(req:Request, res:Response):
-            signin = web.check_signin(req, res)
+            signin = web.signin.check_signin(req, res)
             if signin is not None:
-                return dict(warn=f'Please log in to retrieve session.')
+                raise HTTPException(status_code=401, detail=self.DEFAULT_401_MESSAGE)
             form = await req.form()
             mode = form.get('mode')
             cmd = form.get('cmd')
-            ret = web.options.get_cmd_choices(mode, cmd)
+            ret = web.options.get_cmd_choices(mode, cmd, True)
             return ret
