@@ -1,15 +1,12 @@
 from cmdbox.app import common
 from cmdbox.app.features.web import cmdbox_web_gui
 from cmdbox.app.web import Web
-from fastapi import FastAPI, Request, Response
+from fastapi import FastAPI, Request, Response, HTTPException
 from typing import Dict, Any
 import logging
 
 
 class LoadCmd(cmdbox_web_gui.Gui):
-    def __init__(self):
-        super().__init__()
-
     def route(self, web:Web, app:FastAPI) -> None:
         """
         webモードのルーティングを設定します
@@ -20,9 +17,9 @@ class LoadCmd(cmdbox_web_gui.Gui):
         """
         @app.post('/gui/load_cmd')
         async def load_cmd(req:Request, res:Response):
-            signin = web.check_signin(req, res)
+            signin = web.signin.check_signin(req, res)
             if signin is not None:
-                return dict(warn=f'Please log in to retrieve session.')
+                raise HTTPException(status_code=401, detail=self.DEFAULT_401_MESSAGE)
             form = await req.form()
             title = form.get('title')
             ret = self.load_cmd(web, title)
@@ -42,4 +39,9 @@ class LoadCmd(cmdbox_web_gui.Gui):
         opt_path = web.cmds_path / f"cmd-{title}.json"
         if web.logger.level == logging.DEBUG:
             web.logger.debug(f"web.load_cmd: title={title}, opt_path={opt_path}")
-        return common.loadopt(opt_path)
+        opt = common.loadopt(opt_path, True)
+        if 'title_disabled' in opt: del opt['title_disabled']
+        if 'cmd_disabled' in opt: del opt['cmd_disabled']
+        if 'name_disabled' in opt: del opt['name_disabled']
+        if 'modal_mode' in opt: del opt['modal_mode']
+        return opt
