@@ -1,15 +1,12 @@
 from cmdbox.app import common, feature
 from cmdbox.app.web import Web
-from fastapi import FastAPI, Request, Response
+from fastapi import FastAPI, Request, Response, HTTPException
 from typing import Dict, Any
 import logging
 
 
 
 class LoadPipe(feature.WebFeature):
-    def __init__(self):
-        super().__init__()
-
     def route(self, web:Web, app:FastAPI) -> None:
         """
         webモードのルーティングを設定します
@@ -20,9 +17,9 @@ class LoadPipe(feature.WebFeature):
         """
         @app.post('/gui/load_pipe')
         async def load_pipe(req:Request, res:Response):
-            signin = web.check_signin(req, res)
+            signin = web.signin.check_signin(req, res)
             if signin is not None:
-                return dict(warn=f'Please log in to retrieve session.')
+                raise HTTPException(status_code=401, detail=self.DEFAULT_401_MESSAGE)
             form = await req.form()
             title = form.get('title')
 
@@ -43,4 +40,4 @@ class LoadPipe(feature.WebFeature):
         opt_path = web.pipes_path / f"pipe-{title}.json"
         if web.logger.level == logging.DEBUG:
             web.logger.debug(f"web.load_pipe: title={title}")
-        return common.loadopt(opt_path)
+        return common.loadopt(opt_path, True)
