@@ -1,14 +1,9 @@
 from cmdbox.app import feature
 from cmdbox.app.web import Web
 from fastapi import FastAPI, Request, Response
-from fastapi.responses import HTMLResponse
 
 
 class Usesignout(feature.WebFeature):
-    def __init__(self):
-        super().__init__()
-
-
     def route(self, web:Web, app:FastAPI) -> None:
         """
         webモードのルーティングを設定します
