@@ -1,13 +1,10 @@
 from cmdbox import version
 from cmdbox.app import feature
 from cmdbox.app.web import Web
-from fastapi import FastAPI, Request, Response
+from fastapi import FastAPI, Request, Response, HTTPException
 
 
-class VersionsC(feature.WebFeature):
-    def __init__(self):
-        super().__init__()
-
+class VersionsCmdbox(feature.WebFeature):
     def route(self, web:Web, app:FastAPI) -> None:
         """
         webモードのルーティングを設定します
@@ -18,8 +15,8 @@ class VersionsC(feature.WebFeature):
         """
         @app.get('/versions_cmdbox')
         async def versions_cmdbox(req:Request, res:Response):
-            signin = web.check_signin(req, res)
+            signin = web.signin.check_signin(req, res)
             if signin is not None:
-                return str(dict(warn=f'Please log in to retrieve session.'))
+                raise HTTPException(status_code=401, detail=self.DEFAULT_401_MESSAGE)
             logo = [version.__logo__]
             return logo + version.__description__.split('\n')
