@@ -1,14 +1,11 @@
 from cmdbox.app import feature
 from cmdbox.app.web import Web
-from fastapi import FastAPI, Request, Response
+from fastapi import FastAPI, Request, Response, HTTPException
 from pathlib import Path
 import cmdbox
 
 
 class VersionsUsed(feature.WebFeature):
-    def __init__(self):
-        super().__init__()
-
     def route(self, web:Web, app:FastAPI) -> None:
         """
         webモードのルーティングを設定します
@@ -19,9 +16,9 @@ class VersionsUsed(feature.WebFeature):
         """
         @app.get('/versions_used')
         async def versions_used(req:Request, res:Response):
-            signin = web.check_signin(req, res)
+            signin = web.signin.check_signin(req, res)
             if signin is not None:
-                return str(dict(warn=f'Please log in to retrieve session.'))
+                raise HTTPException(status_code=401, detail=self.DEFAULT_401_MESSAGE)
 
             ret = []
             with open(Path(cmdbox.__file__).parent / 'licenses' / 'files.txt', 'r', encoding='utf-8') as f:
