@@ -86,6 +86,10 @@ fsapi.filer = (svpath, is_local) => {
     cmdbox.file_upload(fsapi.right, svpath, formData, orverwrite=false, progress_func=(e) => {
       cmdbox.progress(0, e.total, e.loaded, '', true, e.total==e.loaded);
     }, success_func=(target, svpath, data) => {
+      if (data != "upload success") {
+        cmdbox.message(data);
+        return;
+      }
       fsapi.tree(target, svpath, target.find('.tree-menu'), false);
     }, error_func=(target, svpath, data) => {
       fsapi.tree(target, svpath, target.find('.tree-menu'), false);
@@ -120,7 +124,14 @@ fsapi.filer = (svpath, is_local) => {
         return list_downloads;
       };
       const path = file_list.pop()
-      const list_downloads = (!path[1] || !path[1]['children']) ? [] : get_list(path[1]);
+      const list_downloads = [];
+      if (path[1] && path[1]['is_dir'] && path[1]['children']!=null && path[1]['children']!=undefined) {
+        list_downloads.push(...get_list(path[1]));
+      } else if (path[1] && !path[1]['is_dir']) {
+        let rpath = path[1]['path'].replace(fsapi.right.find('.filer_address').val(), '');
+        rpath = rpath.startsWith('/') ? rpath.substring(1) : rpath;
+        list_downloads.push({'svpath':path[1]['path'],'rpath':rpath});
+      }
       const jobs = [];
       fsapi.download_now = 0;
       cmdbox.progress(0, list_downloads.length, fsapi.download_now, '', true, false)
@@ -134,7 +145,8 @@ fsapi.filer = (svpath, is_local) => {
         opt['capture_maxsize'] = 1024**3*10;
         //opt['svpath'] = event.originalEvent.dataTransfer.getData('path');
         jobs.push(cmdbox.sv_exec_cmd(opt).then(async res => {
-          if(!res[0] || !res[0]['success']) {
+          if (res && res['success']) res = [res];
+          if (!res[0] || !res[0]['success']) {
             fsapi.download_now ++;
             cmdbox.progress(0, list_downloads.length, fsapi.download_now, '', true, false)
             cmdbox.message(res);
@@ -265,6 +277,7 @@ fsapi.tree = (target, svpath, current_ul_elem, is_local) => {
         res[0]['success']['_'] = fsapi.treemem;
       }
     }
+    if (res && res['success']) res = [res];
     if(!res[0] || !res[0]['success']) {
       cmdbox.message(res);
       target.find('.file-list').html('');
@@ -304,13 +317,14 @@ fsapi.tree = (target, svpath, current_ul_elem, is_local) => {
       if(!node['path']) return;
       target.find('.filer_address').val(node['path']);
       const table = $('<table class="table table-bordered table-hover table-sm">'
-                    + '<thead><tr><th scope="col">-</th><th scope="col">name</th><th scope="col">mime</th><th scope="col">size</th><th scope="col">last</th></tr></thead>'
+                    + '<thead><tr><th class="th" scope="col">-</th><th class="th" scope="col">name</th><th class="th" scope="col">mime</th><th class="th" scope="col">size</th><th class="th" scope="col">last</th></tr></thead>'
                     + '</table>');
       const table_body = $('<tbody></tbody>');
       target.find('.file-list').html('');
       target.find('.file-list').append(table);
       table.append(table_body);
-      const children = node['children'];
+      const upn = {'__':{'name':'..', 'is_dir':true, 'path':node['path'].substring(0, node['path'].lastIndexOf('/')), 'size':0, 'last':''}};
+      const children = {...upn, ...node['children']};
       if(children) {
         // ツリー表示関数の生成
         const mk_tree = (_t, _p, _e, _l) => {return ()=>fsapi.tree(_t, _p, _e, _l)}
@@ -387,6 +401,7 @@ fsapi.tree = (target, svpath, current_ul_elem, is_local) => {
         }};
         // ビューアー関数の生成
         const mk_view = (_p, _mime, _size, _l) => {return ()=>{
+          let bigfile = false;
           if (_size.indexOf('G') >= 0 || _size.indexOf('T') >= 0) {
             cmdbox.message({warn: `The file size is too large to view. (${_size})`});
             return;
@@ -395,11 +410,20 @@ fsapi.tree = (target, svpath, current_ul_elem, is_local) => {
             if (!window.confirm(`The file size is too large to view. (${_size} > 5M)\nDo you still want to open the Viewer?`)) {
               return;
             }
+            bigfile = true;
           }
           const exec_cmd = _l ? fsapi.local_exec_cmd : cmdbox.sv_exec_cmd;
           cmdbox.file_download(fsapi.right, _p, undefined, exec_cmd).then(res => {
             if(!res) return;
-            fsapi.viewer(_p, res['data'], _mime);
+            if (_l) {
+              if (bigfile) cmdbox.message({warn: `Files that are too large may cause display errors in the viewer.`});
+              fsapi.viewer(_p, res['data'], null, _mime);
+            } else {
+              const opt = cmdbox.get_server_opt(false, fsapi.right);
+              const thum_size = "0";
+              const constr = btoa(`${opt['host']}\t${opt['port']}\t${opt['svname']}\t${opt['password']}\t${encodeURIComponent(_p)}\t${opt['scope']}\t${thum_size}`);
+              fsapi.viewer(_p, res['data'], `filer/download/${constr}?r=${cmdbox.random_string(8)}`, _mime);
+            }
           }).finally(() => {
             cmdbox.hide_loading();
           });
@@ -432,7 +456,7 @@ fsapi.tree = (target, svpath, current_ul_elem, is_local) => {
               + `<td><img src="assets/tree-menu/image/${png}"></td>`
               + '<td>'
                 + '<div class="droudown">'
-                  + `<a class="dropdown-toggle" href="#" role="button" data-bs-toggle="dropdown" aria-expanded="false">${_n['name']}</a>`
+                  + `<a class="dropdown-toggle" href="#">${_n['name']}</a>`
                   + '<ul class="dropdown-menu"/>'
                 + '</div>'
               + '</td>'
@@ -469,6 +493,22 @@ fsapi.tree = (target, svpath, current_ul_elem, is_local) => {
           tr.find('.move').off('click').on('click', mk_move(_t, _p, _e, _n["is_dir"], _l));
           tr.find('.view').off('click').on('click', mk_view(_p, tr.find('.mime_type').text(), tr.find('.file_size').text(), _l));
           tr.find('.edit').off('click').on('click', mk_editer(_p, tr.find('.mime_type').text(), tr.find('.file_size').text(), _l));
+          tr.find('.droudown').off('contextmenu').on('contextmenu', (e) => {
+            const fl = target.find('.file-list');
+            fl.find('.dropdown-menu').hide();
+            //tr.find('.dropdown-menu').css('top', `calc(${e.pageY}px - ${fl.css('top')})`).css('left', `calc(${e.pageX}px - ${fl.css('left')})`).show();
+            tr.find('.dropdown-menu').show();
+            e.preventDefault();
+            return false;
+          });
+          if (_n["is_dir"]) {
+            tr.find('.dropdown-toggle').off('click').on('click', mk_tree(_t, _p, _e, _l));
+          }
+          tr.off('contextmenu').on('contextmenu', (e) => {
+            target.find('.file-list').find('.dropdown-menu').hide();
+            e.preventDefault();
+            return false;
+          });
           return tr;
         };
         // ディレクトリを先に表示
@@ -485,6 +525,30 @@ fsapi.tree = (target, svpath, current_ul_elem, is_local) => {
         });
       }
     });
+    const fl_elem = target.find('.file-list').off('contextmenu').on('contextmenu', (e) => {
+      target.find('.file-list').find('.dropdown-menu').hide();
+      target.find('.file-list-dropdown-menu').css('top', e.offsetY).css('left', e.offsetX).show();
+      return false;
+    }).off('click').on('click', (e) => {
+      target.find('.file-list').find('.dropdown-menu').hide();
+    });
+    const ul_elem = $('<ul class="dropdown-menu file-list-dropdown-menu"/>');
+    fl_elem.append(ul_elem);
+    ul_elem.append($('<li><a class="dropdown-item mkdir" href="#">Create Folder</a></li>'));
+    // フォルダ作成関数の生成
+    const _mk_mkdir = (_t, _e, _l) => {return ()=>{
+      const _p = _t.find('.filer_address').val();
+      //_p = _p.substring(0, _p.lastIndexOf('/')+1);
+      const prompt_text = prompt('Enter a new folder name.');
+      if(prompt_text) {
+        const exec_cmd = _l ? fsapi.local_exec_cmd : cmdbox.sv_exec_cmd;
+        cmdbox.file_mkdir(fsapi.right, `${_p=="/"?"":_p}/${prompt_text}`.replace("//","/"), undefined, exec_cmd).then(res => {
+          cmdbox.hide_loading();
+          fsapi.tree(_t, res['path'], _e, _l);
+        });
+      }
+    }};
+    ul_elem.find('.mkdir').off('click').on('click', _mk_mkdir(target, current_ul_elem, is_local));
   }).catch((e) => {
     console.log(e);
   }).finally(() => {
@@ -493,6 +557,7 @@ fsapi.tree = (target, svpath, current_ul_elem, is_local) => {
 }
 // ローカル操作 ==============================================================
 fsapi.safe_fname = (fname) => {
+  fname = fname.replace(/[_]/g, '-_-');
   return fname.replace(/[\s:\\\\/,\.\?\#\$\%\^\&\!\@\*\~\|\<\>\(\)\{\}\[\]\'\"\`]/g, '_');
 }
 fsapi.handles = {};
@@ -587,7 +652,7 @@ fsapi.local_exec_cmd = async (opt) => {
   }
   return {"warn": "Unknown command."}
 };
-fsapi.viewer = (title, data, mime) => {
+fsapi.viewer = (title, data, path, mime) => {
   const viewer = $('#viewer_modal');
   viewer.find('.modal-title').text(title);
   viewer.find('.btn-save').remove();
@@ -595,8 +660,14 @@ fsapi.viewer = (title, data, mime) => {
   viewer_body.html('');
   if (mime.indexOf('image') >= 0) {
     const img = $('<img class="img-fluid" />');
-    img.attr('src', `data:${mime};base64,${data}`);
+    if (path) img.attr('src', path);
+    else img.attr('src', `data:${mime};base64,${data}`);
     viewer_body.append(img);
+  } else if (mime.indexOf('pdf') >= 0) {
+    const pdf = $(`<embed class="w-100 h-100" type="${mime}"></embed>`);
+    if (path) pdf.attr('src', path);
+    else  pdf.attr('src', `data:${mime};base64,${data}`);
+    viewer_body.append(pdf);
   } else {
     cls = '';
     cls = mime == 'application/json' ? 'language-json' : cls;
