@@ -1,8 +1,10 @@
 $(() => {
-  // ダークモード対応
-  cmdbox.change_dark_mode(window.matchMedia('(prefers-color-scheme: dark)').matches);
+  // カラーモード対応
+  cmdbox.change_color_mode();
   // スプリッター初期化
   $('.split-pane').splitPane();
+  // アイコンを表示
+  cmdbox.set_logoicon('.navbar-brand');
   // copyright表示
   cmdbox.copyright();
   // バージョン情報モーダル初期化
